﻿package {
	
	import flash.display.Sprite;
	import flash.geom.Point;
	import com.google.maps.Map;
	import com.google.maps.MapType;
	import com.google.maps.MapEvent;
	import com.google.maps.MapMouseEvent;
	import com.google.maps.LatLng;
	import com.google.maps.overlays.Marker;
	import com.google.maps.overlays.MarkerOptions;
	import com.google.maps.InfoWindowOptions;
	import com.google.maps.controls.MapTypeControl;
	import com.google.maps.controls.ZoomControl;
	import com.google.maps.controls.PositionControl;
	import com.google.maps.controls.ScaleControl;
	import com.google.maps.controls.ControlBase;
	import com.google.maps.controls.OverviewMapControl;
	import com.google.maps.styles.StrokeStyle;
	import com.google.maps.styles.FillStyle;
	
	public class Main extends Sprite {
		
		const API_KEY:String = "";	//Google Maps API Keyを記述
		var googleMaps:Map;	//マップオブジェクト
		var marker1:Marker;	//マーカーオブジェクト
		var marker2:Marker;	//マーカーオブジェクト
		
		//コンストラクタ
		public function Main() {
			initMap();
		}
		
		//Google Maps 作成
		function initMap():void {
			//マップ生成
			googleMaps = new Map();
			//基本設定
			googleMaps.key = API_KEY;	//APIキー登録
			googleMaps.language = "ja";	//言語
			googleMaps.setSize(new Point(stage.stageWidth, stage.stageHeight));	//マップサイズ
			//コントロール表示
			googleMaps.addControl(new PositionControl());		//ポジションコントロールを表示
			googleMaps.addControl(new ZoomControl());			//ズームコントロールを表示
			googleMaps.addControl(new MapTypeControl());		//マップタイプコントロールを表示
			googleMaps.addControl(new OverviewMapControl());	//概要マップの表示
			googleMaps.addControl(new ScaleControl());			//距離の表示
			//イベント設定
			googleMaps.addEventListener(MapEvent.MAP_READY, onMapReady, false, 0, true);
			//配置
			addChild(googleMaps);
		}
		
		//地図生成完了
		function onMapReady(event:MapEvent):void {
			//初期表示設定
			googleMaps.setCenter(new LatLng(35.696898,139.722061), 12, MapType.NORMAL_MAP_TYPE);
			//操作設定
			googleMaps.enableScrollWheelZoom();		//スクロールホイールでのズーム許可
			googleMaps.enableContinuousZoom();		//連続ズームの許可
			googleMaps.enableControlByKeyboard();	//キーボードによるマップ操作の許可
			//イベントリスナーを削除
			googleMaps.removeEventListener(MapEvent.MAP_READY, onMapReady);
			//マーカー追加
			addMarkers();
		}
		
		//マーカー配置
		function addMarkers():void {
			//マーカー1設定
			marker1 = new Marker(new LatLng(35.689516,139.691857));
			marker1.addEventListener(MapMouseEvent.CLICK, onMarkerClick);
			googleMaps.addOverlay(marker1);
			//マーカー2設定
			marker2 = new Marker(new LatLng(35.691043,139.740826), new MarkerOptions( {
				strokeStyle: new StrokeStyle( { color: 0xFF9900 } ),
				fillStyle: new FillStyle( { color: 0x339999, alpha: 0.8 } ),
				label: "IT",
				radius: 15,
				hasShadow: true,
				tooltip: "シンクイット"
			}));
			marker2.addEventListener(MapMouseEvent.CLICK, onMarkerClick);
			googleMaps.addOverlay(marker2);
		}
		
		//マーカークリックイベント
		function onMarkerClick(event:MapMouseEvent):void {
			//インフォウインドウ表示
			var str:String;
			if (event.target == marker1) str = "東京都庁";
			if (event.target == marker2) str = "株式会社インプレスIT";
			event.target.openInfoWindow(new InfoWindowOptions( {
				content: str
			}));
		}
	}
}


